@@ -146,7 +146,7 @@ pub fn write_cirru(xs: &CalcitItems) -> Result<Calcit, String> {
       let options = cirru_parser::CirruWriterOptions { use_inline: false };
       match cirru::calcit_data_to_cirru(a) {
         Ok(v) => Ok(Calcit::Str(cirru_parser::format(&v, options)?)),
-        Err(e) => Err(format!("write-cirru failed, {}", e)),
+        Err(e) => Err(format!("format-cirru failed, {}", e)),
       }
     }
     None => Err(String::from("parse-cirru expected 1 argument")),
@@ -167,7 +167,7 @@ pub fn parse_cirru_edn(xs: &CalcitItems) -> Result<Calcit, String> {
 pub fn write_cirru_edn(xs: &CalcitItems) -> Result<Calcit, String> {
   match xs.get(0) {
     Some(a) => Ok(Calcit::Str(cirru_edn::format(&edn::calcit_to_edn(a), true)?)),
-    None => Err(String::from("write-cirru-edn expected 1 argument")),
+    None => Err(String::from("format-cirru-edn expected 1 argument")),
   }
 }
 
@@ -260,6 +260,10 @@ pub fn invoke_method(
               runner::run_fn(&method_args, def_scope, args, body, def_ns, program_code)
             }
             Calcit::Proc(proc) => builtins::handle_proc(&proc, &method_args),
+            Calcit::Syntax(syn, _ns) => Err(format!(
+              "cannot get syntax here since instance is always evaluated, got: {}",
+              syn
+            )),
             y => Err(format!("expected a function to invoke, got: {}", y)),
           }
         }
